@@ -21,8 +21,6 @@
 from __future__ import annotations
 
 import logging
-import os
-import os.path
 import subprocess
 import sys
 from argparse import Namespace
@@ -34,13 +32,15 @@ from _pytest.capture import CaptureFixture
 from _pytest.logging import LogCaptureFixture
 from _pytest.monkeypatch import MonkeyPatch
 from ansible.utils.sentinel import Sentinel
+from ansible_compat.runtime import Runtime
 
 from ansiblelint import cli, constants, utils
 from ansiblelint.__main__ import initialize_logger
 from ansiblelint.cli import get_rules_dirs
 from ansiblelint.constants import VIOLATIONS_FOUND_RC
 from ansiblelint.file_utils import Lintable
-from ansiblelint.testing import run_ansible_lint
+
+runtime = Runtime()
 
 
 @pytest.mark.parametrize(
@@ -247,30 +247,6 @@ def test_template(template: str, output: str) -> None:
     assert result == output
 
 
-@pytest.mark.parametrize(
-    ("role", "expect_warning"),
-    (
-        ("template_lookup", False),
-        ("template_lookup_missing", True),
-    ),
-)
-def test_template_lookup(role: str, expect_warning: bool) -> None:
-    """Assure lookup plugins used in templates does not trigger Ansible warnings."""
-    task_path = os.path.realpath(
-        os.path.join(
-            os.path.dirname(os.path.realpath(__file__)),
-            "..",
-            "examples",
-            "roles",
-            role,
-            "tasks",
-            "main.yml",
-        )
-    )
-    result = run_ansible_lint("-v", task_path)
-    assert ("Unable to find" in result.stderr) == expect_warning
-
-
 def test_task_to_str_unicode() -> None:
     """Ensure that extracting messages from tasks preserves Unicode."""
     task = dict(fail=dict(msg="unicode é ô à"))
@@ -326,8 +302,6 @@ def test_cli_auto_detect(capfd: CaptureFixture[str]) -> None:
     assert "Identified: .github/" not in out
     # assures that we can parse playbooks as playbooks
     assert "Identified: test/test/always-run-success.yml" not in err
-    # assure that zuul_return missing module is not reported
-    assert "examples/playbooks/mocked_dependency.yml" not in out
     assert "Executing syntax check on examples/playbooks/mocked_dependency.yml" in err
 
 
